apexpy.fortranapex
==================

This module is the interface to the apex Fortran library by Emmert et al. [2010] [1]_. The interface is not documented. Use :class:`apexpy.Apex` for all conversions and calculations. You can find some documentation of the actual Fortran library in the source file `apexsh.f90 <https://github.com/cmeeren/apexpy/blob/master/src/fortranapex/apexsh.f90>`_.

.. [1] Emmert, J. T., A. D. Richmond, and D. P. Drob (2010),
       A computationally compact representation of Magnetic-Apex
       and Quasi-Dipole coordinates with smooth base vectors,
       J. Geophys. Res., 115(A8), A08322, :doi:`10.1029/2010JA015326`.